==> haskell-czipwith-1.0.1.4-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-czipwith.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 czipwith
version:              1.0.1.4
visibility:           public
id:                   czipwith-1.0.1.4-Jp7vTrS861m9yr5PK4rujw
key:                  czipwith-1.0.1.4-Jp7vTrS861m9yr5PK4rujw
license:              BSD-3-Clause
copyright:            Copyright (C) 2017-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/czipwith/
synopsis:             CZipWith class and deriving via TH
description:
    A typeclass similar to Data.Distributive, but for
    data parameterised with a type constructor. The name
    comes from the resemblance of its method to the regular
    zipWith function. The abstraction is useful for example
    for program config handling.

category:             Data
abi:                  c76f501c9f086f6cc8b9d89e03cd9dae
exposed:              True
exposed-modules:      Data.CZipWith
import-dirs:          /usr/lib/ghc-9.2.8/site-local/czipwith-1.0.1.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/czipwith-1.0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-czipwith
hs-libraries:         HSczipwith-1.0.1.4-Jp7vTrS861m9yr5PK4rujw
depends:              base-4.16.4.0 template-haskell-2.18.0.0
haddock-interfaces:   /usr/share/doc/haskell-czipwith/html/czipwith.haddock
haddock-html:         /usr/share/doc/haskell-czipwith/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-czipwith-1.0.1.4-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-czipwith.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 czipwith
version:              1.0.1.4
visibility:           public
id:                   czipwith-1.0.1.4-8vMendnOz0CIkhtB7GTTbB
key:                  czipwith-1.0.1.4-8vMendnOz0CIkhtB7GTTbB
license:              BSD-3-Clause
copyright:            Copyright (C) 2017-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/czipwith/
synopsis:             CZipWith class and deriving via TH
description:
    A typeclass similar to Data.Distributive, but for
    data parameterised with a type constructor. The name
    comes from the resemblance of its method to the regular
    zipWith function. The abstraction is useful for example
    for program config handling.

category:             Data
abi:                  23be8dae5efea7cebe4987774598de22
exposed:              True
exposed-modules:      Data.CZipWith
import-dirs:          /usr/lib/ghc-9.4.8/site-local/czipwith-1.0.1.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/czipwith-1.0.1.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/czipwith-1.0.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-czipwith
hs-libraries:         HSczipwith-1.0.1.4-8vMendnOz0CIkhtB7GTTbB
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-czipwith/html/czipwith.haddock
haddock-html:         /usr/share/doc/haskell-czipwith/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
